summaryrefslogtreecommitdiff
path: root/firmware/include/vboot_api.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/include/vboot_api.h')
-rw-r--r--firmware/include/vboot_api.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/firmware/include/vboot_api.h b/firmware/include/vboot_api.h
index 9aa7f0ad..b6748fc8 100644
--- a/firmware/include/vboot_api.h
+++ b/firmware/include/vboot_api.h
@@ -524,7 +524,7 @@ enum VbScreenType_t {
VB_SCREEN_RECOVERY_INSERT = 0x202, /* Recovery - insert recovery image */
VB_SCREEN_RECOVERY_NO_GOOD = 0x203, /* Recovery - inserted image invalid */
VB_SCREEN_RECOVERY_TO_DEV = 0x204, /* Recovery - confirm dev mode */
- VB_SCREEN_RECOVERY_TO_NORM = 0x205, /* Recovery - confirm normal mode */
+ VB_SCREEN_DEVELOPER_TO_NORM = 0x205, /* Developer - confirm normal mode */
};
/* Initialize and clear the display. Set width and height to the screen